@@ -7,14 +7,15 @@ class Automation:
     default_attributes = {
         'id': None,     # int64 - Automation ID
         'automation': None,     # string - Automation type
+        'trigger': None,     # string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, or `email`.
+        'interval': None,     # string - If trigger is `daily`, this specifies how often to run this automation.  One of: `day`, `week`, `week_end`, `month`, `month_end`, `quarter`, `quarter_end`, `year`, `year_end`
+        'next_process_on': None,     # string - If trigger is `daily`, date this automation will next run.
+        'schedule': None,     # object - If trigger is `custom_schedule`, Custom schedule description for when the automation should be run.
         'source': None,     # string - Source Path
         'destination': None,     # string - Destination Path
         'destination_replace_from': None,     # string - If set, this string in the destination path will be replaced with the value in `destination_replace_to`.
         'destination_replace_to': None,     # string - If set, this string will replace the value `destination_replace_from` in the destination filename. You can use special patterns here.
-        'interval': None,     # string - How often to run this automation?  One of: `day`, `week`, `week_end`, `month`, `month_end`, `quarter`, `quarter_end`, `year`, `year_end`
-        'next_process_on': None,     # string - Date this automation will next run.
         'path': None,     # string - Path on which this Automation runs.  Supports globs. This must be slash-delimited, but it must neither start nor end with a slash. Maximum of 5000 characters.
-        'realtime': None,     # boolean - Does this automation run in real time?  This is a read-only property based on automation type.
         'user_id': None,     # int64 - User ID of the Automation's creator.
         'user_ids': None,     # array - IDs of Users for the Automation (i.e. who to Request File from)
         'group_ids': None,     # array - IDs of Groups for the Automation (i.e. who to Request File from)
@@ -36,7 +37,7 @@ class Automation:
         return {k: getattr(self, k, None) for k in Automation.default_attributes if getattr(self, k, None) is not None}
 
     # Parameters:
-    #   automation (required) - string - Type of automation.  One of: `create_folder`, `request_file`, `request_move`
+    #   automation (required) - string - Automation type
     #   source - string - Source Path
     #   destination - string - Destination Path
     #   destination_replace_from - string - If set, this string in the destination path will be replaced with the value in `destination_replace_to`.
@@ -45,6 +46,8 @@ class Automation:
     #   path - string - Path on which this Automation runs.  Supports globs.
     #   user_ids - string - A list of user IDs the automation is associated with. If sent as a string, it should be comma-delimited.
     #   group_ids - string - A list of group IDs the automation is associated with. If sent as a string, it should be comma-delimited.
+    #   schedule - object - Custom schedule for running this automation.
+    #   trigger - string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, or `email`.
     def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
@@ -77,6 +80,8 @@ class Automation:
             raise InvalidParameterError("Bad parameter: user_ids must be an str")
         if "group_ids" in params and not isinstance(params["group_ids"], str):
             raise InvalidParameterError("Bad parameter: group_ids must be an str")
+        if "trigger" in params and not isinstance(params["trigger"], str):
+            raise InvalidParameterError("Bad parameter: trigger must be an str")
         response, _options = Api.send_request("PATCH", "/automations/{id}".format(id=params['id']), params, self.options)
         return response.data
 
@@ -161,7 +166,7 @@ def get(id, params = None, options = None):
     find(id, params, options)
 
 # Parameters:
-#   automation (required) - string - Type of automation.  One of: `create_folder`, `request_file`, `request_move`
+#   automation (required) - string - Automation type
 #   source - string - Source Path
 #   destination - string - Destination Path
 #   destination_replace_from - string - If set, this string in the destination path will be replaced with the value in `destination_replace_to`.
@@ -170,6 +175,8 @@ def get(id, params = None, options = None):
 #   path - string - Path on which this Automation runs.  Supports globs.
 #   user_ids - string - A list of user IDs the automation is associated with. If sent as a string, it should be comma-delimited.
 #   group_ids - string - A list of group IDs the automation is associated with. If sent as a string, it should be comma-delimited.
+#   schedule - object - Custom schedule for running this automation.
+#   trigger - string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, or `email`.
 def create(params = None, options = None):
     if "automation" in params and not isinstance(params["automation"], str):
         raise InvalidParameterError("Bad parameter: automation must be an str")
@@ -189,13 +196,17 @@ def create(params = None, options = None):
         raise InvalidParameterError("Bad parameter: user_ids must be an str")
     if "group_ids" in params and not isinstance(params["group_ids"], str):
         raise InvalidParameterError("Bad parameter: group_ids must be an str")
+    if "schedule" in params and not isinstance(params["schedule"], dict):
+        raise InvalidParameterError("Bad parameter: schedule must be an dict")
+    if "trigger" in params and not isinstance(params["trigger"], str):
+        raise InvalidParameterError("Bad parameter: trigger must be an str")
     if "automation" not in params:
         raise MissingParameterError("Parameter missing: automation")
     response, options = Api.send_request("POST", "/automations", params, options)
     return Automation(response.data, options)
 
 # Parameters:
-#   automation (required) - string - Type of automation.  One of: `create_folder`, `request_file`, `request_move`
+#   automation (required) - string - Automation type
 #   source - string - Source Path
 #   destination - string - Destination Path
 #   destination_replace_from - string - If set, this string in the destination path will be replaced with the value in `destination_replace_to`.
@@ -204,6 +215,8 @@ def create(params = None, options = None):
 #   path - string - Path on which this Automation runs.  Supports globs.
 #   user_ids - string - A list of user IDs the automation is associated with. If sent as a string, it should be comma-delimited.
 #   group_ids - string - A list of group IDs the automation is associated with. If sent as a string, it should be comma-delimited.
+#   schedule - object - Custom schedule for running this automation.
+#   trigger - string - How this automation is triggered to run. One of: `realtime`, `daily`, `custom_schedule`, `webhook`, or `email`.
 def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -230,6 +243,10 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: user_ids must be an str")
     if "group_ids" in params and not isinstance(params["group_ids"], str):
         raise InvalidParameterError("Bad parameter: group_ids must be an str")
+    if "schedule" in params and not isinstance(params["schedule"], dict):
+        raise InvalidParameterError("Bad parameter: schedule must be an dict")
+    if "trigger" in params and not isinstance(params["trigger"], str):
+        raise InvalidParameterError("Bad parameter: trigger must be an str")
     if "id" not in params:
         raise MissingParameterError("Parameter missing: id")
     if "automation" not in params:
