@@ -12,6 +12,7 @@ class Site:
         'allowed_2fa_method_yubi': None,     # boolean - Is yubikey two factor authentication allowed?
         'admin_user_id': None,     # int64 - User ID for the main site administrator
         'allow_bundle_names': None,     # boolean - Are manual Bundle names allowed?
+        'allowed_countries': None,     # string - Comma seperated list of allowed Country codes
         'allowed_ips': None,     # string - List of allowed IP addresses
         'ask_about_overwrites': None,     # boolean - If false, rename conflicting files instead of asking for overwrite confirmation.  Only applies to web interface.
         'bundle_expiration': None,     # int64 - Site-wide Bundle expiration in days
@@ -29,10 +30,12 @@ class Site:
         'desktop_app': None,     # boolean - Is the desktop app enabled?
         'desktop_app_session_ip_pinning': None,     # boolean - Is desktop app session IP pinning enabled?
         'desktop_app_session_lifetime': None,     # int64 - Desktop app session lifetime (in hours)
+        'disallowed_countries': None,     # string - Comma seperated list of disallowed Country codes
         'disable_notifications': None,     # boolean - Are notifications disabled?
         'disable_password_reset': None,     # boolean - Is password reset disabled?
         'domain': None,     # string - Custom domain
         'email': None,     # email - Main email for this site
+        'reply_to_email': None,     # email - Reply-to email for this site
         'non_sso_groups_allowed': None,     # boolean - If true, groups can be manually created / modified / deleted by Site Admins. Otherwise, groups can only be managed via your SSO provider.
         'non_sso_users_allowed': None,     # boolean - If true, users can be manually created / modified / deleted by Site Admins. Otherwise, users can only be managed via your SSO provider.
         'folder_permissions_groups_only': None,     # boolean - If true, permissions for this site must be bound to a group (not a user). Otherwise, permissions must be bound to a user.
@@ -117,7 +120,11 @@ class Site:
         'disable_users_from_inactivity_period_days': None,     # int64 - If greater than zero, users will unable to login if they do not show activity within this number of days.
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
@@ -132,7 +139,7 @@ class Site:
 # Parameters:
 #   format - string
 #   site - object
-def get(params = {}, options = {}):
+def get(params = None, options = None):
     if "format" in params and not isinstance(params["format"], str):
         raise InvalidParameterError("Bad parameter: format must be an str")
     if "site" in params and not isinstance(params["site"], dict):
@@ -143,7 +150,7 @@ def get(params = {}, options = {}):
 # Parameters:
 #   format - string
 #   site - object
-def get_usage(params = {}, options = {}):
+def get_usage(params = None, options = None):
     if "format" in params and not isinstance(params["format"], str):
         raise InvalidParameterError("Bad parameter: format must be an str")
     if "site" in params and not isinstance(params["site"], dict):
@@ -156,6 +163,7 @@ def get_usage(params = {}, options = {}):
 #   subdomain - string - Site subdomain
 #   domain - string - Custom domain
 #   email - string - Main email for this site
+#   reply_to_email - string - Reply-to email for this site
 #   allow_bundle_names - boolean - Are manual Bundle names allowed?
 #   bundle_expiration - int64 - Site-wide Bundle expiration in days
 #   overage_notify - boolean - Notify site email of overages?
@@ -181,7 +189,9 @@ def get_usage(params = {}, options = {}):
 #   user_lockout_within - int64 - Number of hours for user lockout window
 #   user_lockout_lock_period - int64 - How many hours to lock user out for failed password?
 #   include_password_in_welcome_email - boolean - Include password in emails to new users?
+#   allowed_countries - string - Comma seperated list of allowed Country codes
 #   allowed_ips - string - List of allowed IP addresses
+#   disallowed_countries - string - Comma seperated list of disallowed Country codes
 #   days_to_retain_backups - int64 - Number of days to keep deleted files
 #   max_prior_passwords - int64 - Number of prior passwords to disallow
 #   password_validity_days - int64 - Number of days password is valid
@@ -254,7 +264,7 @@ def get_usage(params = {}, options = {}):
 #   ldap_password_change - string - New LDAP password.
 #   ldap_password_change_confirmation - string - Confirm new LDAP password.
 #   smtp_password - string - Password for SMTP server.
-def update(params = {}, options = {}):
+def update(params = None, options = None):
     if "name" in params and not isinstance(params["name"], str):
         raise InvalidParameterError("Bad parameter: name must be an str")
     if "subdomain" in params and not isinstance(params["subdomain"], str):
@@ -263,6 +273,8 @@ def update(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: domain must be an str")
     if "email" in params and not isinstance(params["email"], str):
         raise InvalidParameterError("Bad parameter: email must be an str")
+    if "reply_to_email" in params and not isinstance(params["reply_to_email"], str):
+        raise InvalidParameterError("Bad parameter: reply_to_email must be an str")
     if "bundle_expiration" in params and not isinstance(params["bundle_expiration"], int):
         raise InvalidParameterError("Bad parameter: bundle_expiration must be an int")
     if "welcome_email_cc" in params and not isinstance(params["welcome_email_cc"], str):
@@ -285,8 +297,12 @@ def update(params = {}, options = {}):
         raise InvalidParameterError("Bad parameter: user_lockout_within must be an int")
     if "user_lockout_lock_period" in params and not isinstance(params["user_lockout_lock_period"], int):
         raise InvalidParameterError("Bad parameter: user_lockout_lock_period must be an int")
+    if "allowed_countries" in params and not isinstance(params["allowed_countries"], str):
+        raise InvalidParameterError("Bad parameter: allowed_countries must be an str")
     if "allowed_ips" in params and not isinstance(params["allowed_ips"], str):
         raise InvalidParameterError("Bad parameter: allowed_ips must be an str")
+    if "disallowed_countries" in params and not isinstance(params["disallowed_countries"], str):
+        raise InvalidParameterError("Bad parameter: disallowed_countries must be an str")
     if "days_to_retain_backups" in params and not isinstance(params["days_to_retain_backups"], int):
         raise InvalidParameterError("Bad parameter: days_to_retain_backups must be an int")
     if "max_prior_passwords" in params and not isinstance(params["max_prior_passwords"], int):
