@@ -18,6 +18,8 @@ class SsoStrategy:
         'saml_provider_sso_target_url': None,     # string - Identity provider SSO endpoint if saml_provider_metadata_url is not available.
         'scim_authentication_method': None,     # string - SCIM authentication type.
         'scim_username': None,     # string - SCIM username.
+        'scim_oauth_access_token': None,     # string - SCIM OAuth Access Token.
+        'scim_oauth_access_token_expires_at': None,     # string - SCIM OAuth Access Token Expiration Time.
         'subdomain': None,     # string - Subdomain
         'provision_users': None,     # boolean - Auto-provision users?
         'provision_groups': None,     # boolean - Auto-provision group membership based on group memberships on the SSO side?
@@ -28,11 +30,13 @@ class SsoStrategy:
         'provision_group_exclusion': None,     # string - Comma-separated list of group names for groups (with optional wildcards) that will be excluded from auto-provisioning.
         'provision_group_inclusion': None,     # string - Comma-separated list of group names for groups (with optional wildcards) that will be auto-provisioned.
         'provision_group_required': None,     # string - Comma or newline separated list of group names (with optional wildcards) to require membership for user provisioning.
+        'provision_site_admin_groups': None,     # string - Comma-separated list of group names whose members will be created as Site Admins.
         'provision_attachments_permission': None,     # boolean - Auto-provisioned users get Sharing permission?
         'provision_dav_permission': None,     # boolean - Auto-provisioned users get WebDAV permission?
         'provision_ftp_permission': None,     # boolean - Auto-provisioned users get FTP permission?
         'provision_sftp_permission': None,     # boolean - Auto-provisioned users get SFTP permission?
         'provision_time_zone': None,     # string - Default time zone for auto provisioned users.
+        'provision_company': None,     # string - Default company for auto provisioned users.
         'ldap_base_dn': None,     # string - Base DN for looking up users in LDAP server
         'ldap_domain': None,     # string - Domain name that will be appended to LDAP usernames
         'enabled': None,     # boolean - Is strategy enabled?
@@ -45,7 +49,11 @@ class SsoStrategy:
         'ldap_username_field': None,     # string - LDAP username field
     }
 
-    def __init__(self, attributes={}, options={}):
+    def __init__(self, attributes=None, options=None):
+        if not isinstance(attributes, dict):
+            attributes = {}
+        if not isinstance(options, dict):
+            options = {}
         self.set_attributes(attributes)
         self.options = options
 
@@ -58,29 +66,25 @@ class SsoStrategy:
 
 
 # Parameters:
-#   page - int64 - Current page number.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
-#   action - string - Deprecated: If set to `count` returns a count of matching records rather than the records themselves.
-#   cursor - string - Send cursor to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
-def list(params = {}, options = {}):
-    if "page" in params and not isinstance(params["page"], int):
-        raise InvalidParameterError("Bad parameter: page must be an int")
-    if "per_page" in params and not isinstance(params["per_page"], int):
-        raise InvalidParameterError("Bad parameter: per_page must be an int")
-    if "action" in params and not isinstance(params["action"], str):
-        raise InvalidParameterError("Bad parameter: action must be an str")
+def list(params = None, options = None):
     if "cursor" in params and not isinstance(params["cursor"], str):
         raise InvalidParameterError("Bad parameter: cursor must be an str")
+    if "per_page" in params and not isinstance(params["per_page"], int):
+        raise InvalidParameterError("Bad parameter: per_page must be an int")
     return ListObj(SsoStrategy,"GET", "/sso_strategies", params, options)
 
-def all(params = {}, options = {}):
+def all(params = None, options = None):
     list(params, options)
 
 # Parameters:
 #   id (required) - int64 - Sso Strategy ID.
-def find(id, params = {}, options = {}):
+def find(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
+    if not isinstance(options, dict):
+        options = {}
     params["id"] = id
     if "id" in params and not isinstance(params["id"], int):
         raise InvalidParameterError("Bad parameter: id must be an int")
@@ -89,7 +93,7 @@ def find(id, params = {}, options = {}):
     response, options = Api.send_request("GET", "/sso_strategies/{id}".format(id=params['id']), params, options)
     return SsoStrategy(response.data, options)
 
-def get(id, params = {}, options = {}):
+def get(id, params = None, options = None):
     find(id, params, options)
 
 def new(*args, **kwargs):
